<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Gestor de Usuarios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administración</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Añadir un nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Añadir una Cuenta de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Enter password for new user</source>
        <translation>Ingrese la contraseña para el nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>password</source>
        <translation>contraseña</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Reenter password for new user</source>
        <translation>Vuelva a ingresar la contraseña para el nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>confirm password</source>
        <translation>confirmar contraseña</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Username of new user</source>
        <translation>Nombre de usuario del nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User login name:</source>
        <translation>Nombre de inicio de sesión de usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Enter username of new user</source>
        <translation>Ingrese el nombre del nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <location filename="../mainwindow.ui" line="472"/>
        <source>username</source>
        <translation>nombre de usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.ui" line="258"/>
        <source>Password for new user</source>
        <translation>Contraseña para el nuevo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Confirm user password:</source>
        <translation>Confirmar contraseña de usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>User password:</source>
        <translation>Contraseña de usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Grant this user administrative rights to the system (sudo)</source>
        <translation>Conceder a este usuario derechos administrativos sobre el sistema (sudo)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Delete User Account</source>
        <translation>Eliminar una Cuenta de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Select user</source>
        <translation>Seleccionar usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Select user to delete</source>
        <translation>Seleccionar usuario a eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>User to delete:</source>
        <translation>Usuario a eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Borrar también el directorio home del usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Delete user home directory</source>
        <translation>Eliminar el directorio home del usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Rename User Account</source>
        <translation>Renombrar la Cuenta de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Select user to modify:</source>
        <translation>Seleccionar usuario a modificar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>New user name:</source>
        <translation>Nuevo nombre de usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Change User Password</source>
        <translation>Cambiar Contraseña de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>new password</source>
        <translation>nueva contraseña</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Confirm new password:</source>
        <translation>Confirmar nueva contraseña:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>confirm new password</source>
        <translation>Confirmar nueva contraseña</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>New user password:</source>
        <translation>Nueva contraseña de usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Repair a user configuration</source>
        <translation>Reparar una configuración de usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="1393"/>
        <source>Modify User Account</source>
        <translation>Modificar la Cuenta de Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Select user to repair</source>
        <translation>Seleccione el usuario a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>User to change:</source>
        <translation>Usuario a cambiar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <source>Restore Defaults</source>
        <translation>Restaurar predeterminado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Restaurar las configuraciones del navegador a los valores por defecto de MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Configuración de Mozilla (Iceweasel o Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Restaurar las afiliaciones de grupos a los valores por defecto de MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Group memberships</source>
        <translation>Afiliaciones de Grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Change Autologin Settings</source>
        <translation>Cambiar la configuración de inicio de sesión automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>Log in automatically</source>
        <translation>Iniciar sesión automáticamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>Require password to log in</source>
        <translation>Solicitar contraseña para iniciar sesión</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Copy/Sync</source>
        <translation>Copiar/Sincronizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Copy Between Desktops</source>
        <translation>Copiar entre escritorios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <location filename="../mainwindow.ui" line="922"/>
        <source>Select desktop to copy from</source>
        <translation>Seleccione el escritorio desde el que copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>Select to only copy files</source>
        <translation>Seleccionar para copiar solo archivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <source>Copy only</source>
        <translation>Solo copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select desktop to copy to</source>
        <translation>Seleccionar escritorio al que copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="909"/>
        <source>Copy to:</source>
        <translation>Copiar en:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="931"/>
        <source>Copy from:</source>
        <translation>Copiado de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="944"/>
        <source>Select to copy and then delete differences</source>
        <translation>Seleccionar copiar y luego borrar las diferencias</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Sync</source>
        <translation>Sincronización</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="993"/>
        <source>Select to copy/sync Shared</source>
        <translation>Seleccionar para copia/sincronización compartida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="996"/>
        <source>Shared folder</source>
        <translation>Carpeta compartida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Select to copy/sync entire home</source>
        <translation>Seleccionar para copia/sincronización completa del directorio home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Entire home</source>
        <translation>Todo home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1028"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Seleccione para copiar/sincronizar la configuración del navegador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1031"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Configuración de Mozilla (Firefox o Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>Select to copy/sync Documents</source>
        <translation>Seleccionar para copiar/sincronizar Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1047"/>
        <source>Documents folder</source>
        <translation>Carpeta Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1054"/>
        <source>What to copy/sync:</source>
        <translation>Qué copiar/sincronizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1070"/>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1100"/>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Status of the changes</source>
        <translation>Estado de los cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1119"/>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Progress of the changes</source>
        <translation>Progreso de los cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1172"/>
        <source>Add/Remove Groups</source>
        <translation>Añadir/Eliminar Grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <source>Add Group</source>
        <translation>Añadir un Grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1211"/>
        <source>Enter name of new group</source>
        <translation>Introduzca el nombre del nuevo grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>groupname</source>
        <translation>nombredelgrupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation>Crear un grupo con GID &gt; 1000</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Create a user-level group</source>
        <translation>Crear un grupo nivel-usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ingrese el nombre del nuevo grupo&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <source>Group name:</source>
        <translation>Nombre del Grupo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1281"/>
        <source>Delete Group</source>
        <translation>Eliminar Grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Seleccione el grupo a eliminar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Select group to delete:</source>
        <translation>Seleccione el grupo para eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation>*Vuelva a comprobar sus selecciones antes de aplicarlas, eliminar un grupo erróneo puede romper su sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1381"/>
        <source>Group Membership</source>
        <translation>Afiliacion del Grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Grupos a los que pertenece el usuario (cambie los grupos seleccionando/deseleccionando las casillas correspondientes):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1478"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation>*Por favor, compruebe sus selecciones antes de aplicarlas, asignar membresías de grupo erróneas puede romper su sistema. Si ha cometido un error, utilice la opción de restaurar la pertenencia a un grupo en la pestaña de Opciones para restablecer los valores predeterminados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Seleccione el usuario a cambiar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar los cambios y luego salir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1586"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1593"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1637"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Apply any changes</source>
        <translation>Aplicar los cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1654"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <location filename="../mainwindow.cpp" line="155"/>
        <location filename="../mainwindow.cpp" line="163"/>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="190"/>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="757"/>
        <location filename="../mainwindow.cpp" line="783"/>
        <location filename="../mainwindow.cpp" line="813"/>
        <location filename="../mainwindow.cpp" line="970"/>
        <location filename="../mainwindow.cpp" line="1037"/>
        <location filename="../mainwindow.cpp" line="1044"/>
        <location filename="../mainwindow.cpp" line="1049"/>
        <location filename="../mainwindow.cpp" line="1054"/>
        <location filename="../mainwindow.cpp" line="1059"/>
        <source>none</source>
        <translation>ninguno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="744"/>
        <location filename="../mainwindow.cpp" line="977"/>
        <location filename="../mainwindow.cpp" line="986"/>
        <source>browse...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Se reparará la configuración del usuario. Cierre todas las demás aplicaciones ahora. Cuando termine, cierre la sesión o reinicie. ¿Estás seguro de que quieres repararlo ahora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <source>User group membership was restored.</source>
        <translation>Se restauró la pertenencia al grupo de usuarios.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Mozilla settings were reset.</source>
        <translation>La configuración de Mozilla se restableció.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Autologin options</source>
        <translation>Opciones de ingreso automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>El ingreso automático se desactivó para la cuenta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>El ingreso automático se activó para la cuenta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Debe especificar un destino en &quot;copiar a&quot;. No se puede copiar al escritorio activo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Antes de copiar, cierre todas las otras aplicaciones.  Asegúrese de que el destino al que va a copiar posea suficiente espacio para los archivos a copiarse.  Copiar los escritorios puede reescribir o borrar sus archivos y preferencias en el escritorio de destino. ¿En verdad desea proceder? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Synchronizing desktop...</source>
        <translation>Sincronizando el escritorio...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Copying desktop...</source>
        <translation>Copiando el escritorio...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>El nombre de usuario debe ser de al menos 2 caracteres. Por favor seleccione un nombre más largo antes de proceder.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>El nombre de usuario no puede contener caracteres especiales ni espacios.
Por favor elija otro nombre antes de continuar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Lo sentimos, este nombre está en uso. Por favor ingrese un nombre diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Claves introducidas no concuerdan. Favor intente de nuevo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <location filename="../mainwindow.cpp" line="422"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Contraseña debe que tener mínimo 2 caracteres. Favor coloque una más larga antes de proceder. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>The user was added ok.</source>
        <translation>Se agregó con éxito el usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Failed to add the user.</source>
        <translation>No se pudo agregar el usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>Password successfully changed.</source>
        <translation>Clave cambiado con éxito. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Failed to change password.</source>
        <translation>Fallo en cambiar clave. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Esta acción no se puede deshacer. ¿Desea realmente borrar al usuario %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>The user has been deleted.</source>
        <translation>Se ha borrado el usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>Failed to delete the user.</source>
        <translation>No se pudo borrar el usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>El nombre del grupo debe ser de al menos 2 caracteres.  Por favor, seleccione uno más largo antes de continuar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="485"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>El nombre del grupo debe estar en minúscula 
y no puede incluir espacios o caracteres especiales.
Escoja otro antes de continuar, por favor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Lo sentimos, ese nombre de grupo ya existe. Por favor ingrese un nombre diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>The system group was added ok.</source>
        <translation>El grupo se agregó con éxito al sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Failed to add the system group.</source>
        <translation>No se pudo agregar el grupo al sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Esta acción no se puede deshacer. ¿Desea realmente borrar el grupo %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation>Esta acción no se puede deshacer. ¿Está seguro de que desea eliminar los siguientes grupos: %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Failed to delete the group.</source>
        <translation>No se pudo borrar el grupo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Group: %1</source>
        <translation>Grupo: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>The group has been deleted.</source>
        <translation>Se ha borrado el grupo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>The groups have been deleted.</source>
        <translation>Los grupos han sido eliminados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="549"/>
        <source>The changes have been applied.</source>
        <translation>Se aplicaron todos los cambios.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Failed to apply group changes</source>
        <translation>No se pudo aplicar los cambios a los grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>The selected user name is currently in use.</source>
        <translation>El nombre de usuario seleccionado está actualmente en uso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Para renombrar este usuario, cierre la sesión y vuelva a iniciarla con otra cuenta de usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>El nombre del usuario debe estar en minúscula
y no puede incluir espacios o caracteres especiales.
Escoja otro antes de continuar, por favor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Lo sentimos, este nombre ya existe en su sistema. Por favor ingrese un nombre diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="595"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Error al renombrar el usuario. Asegúrese que el usuario no haya iniciado sesión, es posible que deba reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>The user was renamed.</source>
        <translation>El usuario fue renombrado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="631"/>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sincronizando el escritorio...OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>Copying desktop...ok</source>
        <translation>Copiando el escritorio...OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sincronizando el escritorio...falló</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Copying desktop...failed</source>
        <translation>Copiando el escritorio...falló</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>Confirmation</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>Proceso no realizado. ¿Está seguro de que desea salir de la aplicación?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="942"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="943"/>
        <source>Version: </source>
        <translation>Versión: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="944"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Configuración simple de usuarios para MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="946"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="947"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="961"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="978"/>
        <source>Select folder to copy to</source>
        <translation>Seleccione carpeta en donde copiar</translation>
    </message>
</context>
<context>
    <name>PassEdit</name>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Negligible</source>
        <translation>Insignificante</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Very weak</source>
        <translation>Muy débil</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Weak</source>
        <translation>Débil</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Moderate</source>
        <translation>Moderado</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Strong</source>
        <translation>Fuerte</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Very strong</source>
        <translation>Muy fuerte</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="164"/>
        <source>Password strength: %1</source>
        <translation>Fuerza de la contraseña: %1</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="200"/>
        <source>Hide the password</source>
        <translation>Ocultar la contraseña</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="200"/>
        <source>Show the password</source>
        <translation>Mostrar la contraseña</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <location filename="../about.cpp" line="61"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <location filename="../main.cpp" line="68"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que ha iniciado sesión como root, cierre la sesión e inicie sesión como usuario normal para usar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>You must run this program with admin access.</source>
        <translation>Debe ejecutar este programa con acceso de administrador.</translation>
    </message>
</context>
</TS>
